@@ -35,11 +35,11 @@ class Act(object):
     """ Container class for actor resolve time initialization and runtime operation """
     __slots__ = ('frame', 'context', 'act', 'actor',
                  'registrar', 'inits', 'ioinits', 'parms',
-                 'prerefs', 'human', 'count')
+                 'prerefs', 'human', 'count', 'inode')
 
     def __init__(self, frame=None, context=None, act=None, actor=None,
                  registrar=None, inits=None, ioinits=None, parms=None,
-                 prerefs=None, human='', count=0, **kwa ):
+                 prerefs=None, human='', count=0, inode=None, **kwa ):
         """
         Initialization method for instance.
 
@@ -56,6 +56,7 @@ class Act(object):
             .prerefs = dictionary of init, ioinit, and parm refs to resolve
             .human = human friendly version of action declaration
             .count = line count in floscript of action declaration
+            .inode = actor level inode for ioinits if any
 
         Share path resolution
             act.resolve aggregates ioinits from registry,  act.ioinits, and act.prerefs
@@ -77,6 +78,7 @@ class Act(object):
         self.prerefs = prerefs if prerefs else None # store None if empty dict
         self.human = human  # human readable version of FloScript declaration
         self.count = count  # line number or count of FloScript declaration
+        self.inode = inode  # inode None means ignore
 
     def clone(self):
         """ Return clone of self in support of framer cloning
@@ -155,14 +157,20 @@ class Act(object):
                             parms[field] = src[field]
             parms.update(self.parms or odict())  # 'do with' overrides from, self.parms may be None
 
+            #  compute .inode
+            self.inode = (self.ioinits or odict()).get('inode', ioinits.get('inode', self.inode))
+            if self.inode is not None and not isinstance(self.inode, basestring):
+                raise ValueError("Nonstring inode '{0}'".format(self.inode))
+            if self.inode and not self.inode.endswith("."):  # ensure node not share path
+                self.inode = "{0}.".format(self.inode)
+
             rioinits = odict(ioinits)  # save copy registry ioinits to keep ival iown
-            if self.prerefs:  # preinits ioinits dict items  'do for'
+            if self.prerefs and 'ioinits' in self.prerefs:  # preinit ioinits dict items  'do for'
                 # each key is share src path, and value is list of src fields
-                inode = (self.ioinits or odict()).get('inode', ioinits.get('inode', ''))
-                if inode and not inode.endswith("."):  # ensure is node not share path
-                    inode = "{0}.".format(inode)
-                for src, fields in self.prerefs.get('ioinits', {}).items():   # now resolve new src paths
-                    src = self.resolvePath(ipath=src, inode=inode, warn=True) # now a share
+                if self.inode is None:  # since prerefs then inode may not be None
+                    self.inode = ""
+                for src, fields in self.prerefs['ioinits'].items():  # now resolve new src paths
+                    src = self.resolvePath(ipath=src, warn=True)  # now a share
                     if not fields:  # default is use existing fields
                         fields = self._prepareSrcFields(src, fields)
                     for field in fields:  # assumes each src fld value pre inited with ipath
@@ -177,20 +185,19 @@ class Act(object):
                         val['ipath'] = ioinits[key]  # replace old ipath witn new
                         ioinits[key] = val # restore default ival iown
 
+
             if ioinits:
-                inode, iois = actor._initio(ioinits)
+                iois = actor._initio(ioinits)  # .inode may be changed in here
                 if iois:
                     for key, ioi in iois.items():
                         if key == "inode":  # compute the final inode
-                            share = actor._resolvePath(ipath="",
+                            share = actor._resolvePath(ipath="", # empty to force
                                                        ival=ioi.get('ival'),
-                                                       iown=ioi.get('iown'),
-                                                       inode=ioi['ipath'])  # empty to force
+                                                       iown=ioi.get('iown'))
                         else:
                             share = actor._resolvePath(ipath=ioi['ipath'],
                                                        ival=ioi.get('ival'),
-                                                       iown=ioi.get('iown'),
-                                                       inode=inode)
+                                                       iown=ioi.get('iown'))
                         if actor._Parametric:
                             if key in parms:
                                 msg = "ResolveError: Parm and Ioi with same name"
@@ -213,7 +220,7 @@ class Act(object):
             self.parms.update(self.actor._resolve(**self.parms)) # resolve sub acts
             self.actor._prepare(**self.parms)
 
-    def resolvePath(self, ipath, ival=None, iown=None, inode=None, warn=False):
+    def resolvePath(self, ipath, ival=None, iown=None, warn=False):
         """
         Returns resolved Share or Node instance from ipath
         ipath may be path name of share or node
@@ -226,13 +233,10 @@ class Act(object):
         iown is optional ownership if True then overwrite if exists
                otherwise do not overwrite
 
-        inode is optional actor inode value for ipath used for ioinits
-
         if warn then will complain if the share is created.
 
         When ipath is empty then resolvePath returns the effective context node
-        path given the actor inode and nested frame inodes and framer inodes
-
+        path given by .inode and nested frame inodes and framer inodes
 
         It allows for substitution into ipath of
         inode, framer,  main framer, frame, main frame, or actor relative names.
@@ -291,7 +295,7 @@ class Act(object):
               self.actor.name is not empty
 
         Any actor could have ioinits saved for them in their ._act  Act
-        If ionits exist then then an inode is part of the ioinits
+        If ionits exist then then an inode should be part of the ioinits
         Currently only the Do verb actors have ioinits. The inode is one of them.
         The ioinits come from two sources. The registry and the do verb per and for
         clauses
@@ -299,12 +303,13 @@ class Act(object):
         _act.ioinits are the do and per clauses
         registry ioints are from the Actor.Ionints class variable
 
-        So inode parameter to Act.resolvePaths inidcates if for ioinit or not.
-        If inode None then ipath is not an actor ioinit and Otherwise even if "" then
-        ipath comes from ioinit and  should handle inode logic.
+        So the .inode attribute indicates if the ipath being resolved is for
+        an ioinit or not.  If .inode is None it is not for an ioinit.
+        Otherwise even if .inode is "" then ipath comes from ioinit and
+        path resolution should handle inode logic.
+
         This would puts all the framer inode prepend
         logic in one place and make it easier to climb the  frame and aux outline
-
         """
         if not (isinstance(ipath, storing.Share) or isinstance(ipath, storing.Node)): # must be pathname
             parts = ipath.split('.') if ipath else []  # [] if ipath is empty
@@ -357,29 +362,33 @@ class Act(object):
 
                 # "" == ".".join([]) == ".".join([""])
 
+                # over frame inode processing
+                frame = self.frame # start at current frame
+                oparts = frame.inode.rstrip(".").split(".") if frame.inode else []
+                while frame and (not oparts or oparts[0] not in ("", "framer")):
+                    if oparts and oparts[0] == "me":  # me relative
+                        del oparts[0]
+                        break  # skip any further over frames
+                    frame = frame.over
+                    if frame and frame.inode:
+                        oparts = frame.inode.rstrip(".").split(".") + oparts
+
                 # already know from above parts not absolute
-                if (inode is not None and (not parts or
+                if (self.inode is not None and (not parts or
                         parts[0] not in ("framer", "me"))):
-                    # prepend inode logic
-                    iparts = inode.rstrip(".").split(".") if inode else []
-                    if not iparts and not fparts:  # use default inode
+                    # prepend act .inode logic
+                    iparts = self.inode.rstrip(".").split(".") if self.inode else []
+                    if not iparts and not oparts and not fparts:  # use default inode
                         iparts = "framer.me.frame.me.actor.me".split(".")
                     parts = iparts + parts  # prepend inode parts
 
                 if not parts or parts[0] not in ("", "framer"):  # not absolute or framer relative
                     if parts and parts[0] == 'me':  # skip frame.inode processing
                         del parts[0]  # parts could be empty now
-                    else:  # process frame.inode and walk up over if any
-                        frame = self.frame # start at current frame
-                        while frame and (not parts or parts[0] not in ("", "framer")):
-                            if frame.inode:
-                                parts = frame.inode.rstrip(".").split(".") + parts
-                            if parts and parts[0] == "me":
-                                del parts[0]
-                                break  # skip any further over frames
-                            frame = frame.over
+                    else:  # prepend over frame inodes
+                        parts = oparts + parts
                     if not parts or parts[0] not in ("", "framer"):
-                        parts = fparts + parts  # prepend fparts
+                        parts = fparts + parts  # prepend fparts framer inodes
 
             if parts and parts[0]:  # not absolute so do relative substitutions
                 if parts[0] == 'framer':  #  framer relative addressing
@@ -639,45 +648,20 @@ class Actor(object):
     def _initio(self, ioinits):
         """
         Compute initializations for ioflo shares from ioinits odict or item list
-        'inode' item in ioinits is special
+        The 'inode' item in ioinits is special. Act.resolve extracts 'inode' from
+        ioinits and assigns to ._act.inode before ._initio is called.
 
         This implements a generic Actor interface protocol for associating the
         io data flow shares to the Actor.
 
-        inode is the computed pathname string of the default share node
-        where shares associated with the Actor instance may be placed when
-        relative addressing is used. It is also the default data store context
+        The ._act.inode attribute holds the pathname string of the default
+        data store node where shares associated with the Actor instance may
+        be placed when relative addressing is used.
+        It is also the default data store context
         for share references by Doer iois. The inode on an actor my be set
         explicitly in the Ioinit class variable or in the actify (doify) decorator
         or by the via clause of a Doer
 
-        The default inode is  'framer.me.frame.me.actor.me.' which is the case
-        when the passed in inode is empty.
-
-        If the inode is provided then if it is absolute, has a leading '.' then
-        it it left as is
-
-        If the inode is relative, has no leading '.' then relative substitution
-        rules apply.
-           If the inode is "me" or starts with "me." then replace the me with
-               the framer inode (frinode). Skip frame inode lookup
-
-           Otherwise apply prepend frame inode lookup
-
-            This occurs if the framer inode (frinode) is empty
-                (which occurs when the via clause is missing for the framer)
-            and the ioinit inode parameter passed in is also empty
-
-        When a via clause exists for the framer then frinode is not empty
-            so the default is not used
-            and the computed inode is either absolute or relative
-
-        When the inode parameter is relative (no leading dot)
-            it is relative to the framer inode
-
-        If the framer is a cloned auxiliary then the inode could be relative
-            to the main framer inode
-
         The values of the items in the **kwa argument may be either strings or
         mappings
 
@@ -744,16 +728,16 @@ class Actor(object):
 
         """
         ioinits = odict(ioinits)  # make copy also allows for item list as parameter
-        inode = ioinits.get('inode', '')
+        #inode = ioinits.get('inode', '')
 
-        if not isinstance(inode, basestring):
-            raise ValueError("Nonstring inode arg '{0}'".format(inode))
+        #if inode and not inode.endswith('.'):  # ensure is a node not share path
+            #inode = "{0}.".format(inode)
 
-        if inode and not inode.endswith('.'):  # ensure is a node not share path
-            inode = "{0}.".format(inode)
+        if self._act.inode is None:  # inode may not be None if ioinits
+            self._act.inode = ""
 
         iois = odict()
-        ioi = odict(ipath=inode)  # create ioi for the inode
+        ioi = odict(ipath=self._act.inode)  # create ioi for the inode
         iois['inode'] = ioi  # inode path resolves so actor has reference to its own inode
         for key, val in ioinits.items():  # assumes keys are basestrings
             if key == 'inode':  # skip inode
@@ -793,7 +777,7 @@ class Actor(object):
             ioi = odict(ipath=ipath, ival=ival, iown=iown)
             iois[key] = ioi
 
-        return (inode, iois)  # inode prepended in act.resolvePath
+        return iois  # inode prepended in act.resolvePath
 
     def _prepare(self, **kwa):
         """ Base method to be overriden in sub classes. Perform post initio setup
@@ -805,7 +789,7 @@ class Actor(object):
         """
         pass
 
-    def _resolvePath(self, ipath, ival=None, iown=None, inode=None, warn=False):
+    def _resolvePath(self, ipath, ival=None, iown=None, warn=False):
         """ Returns resolved Share or Node instance from ipath
             Calls self._act.resolvePath()
             See doc string from Act.resolvePath for detailed description of
@@ -822,7 +806,6 @@ class Actor(object):
             ipath = self._act.resolvePath(ipath=ipath,
                                           ival=ival,
                                           iown=iown,
-                                          inode=inode,
                                           warn=warn)
 
         return ipath
@@ -1354,7 +1337,7 @@ class Rearer(Actor):
                                          count=self._act.count)
 
         if schedule == AUX:  # only current framer
-            framer = framing.resolveFramer(self._act.frame.framer,
+            parms['framer'] = framer = framing.resolveFramer(self._act.frame.framer,
                                             who=self._act.frame.name,
                                             desc='rear aux clone',
                                             contexts=[],
@@ -1396,8 +1379,18 @@ class Rearer(Actor):
 
         return parms
 
-    def action(self, original, clone, schedule, frame, **kw):
-        """Action called by Actor  """
+    def action(self, original, clone, schedule, frame, framer, **kw):
+        """
+        Action called by Actor
+
+        Parameters:
+           original is resolved original moot framer to be cloned
+           clone is clone tag (not used currently)
+           schedule is clone schedule
+           frame is resolved frame for reared clone
+           framer is resolved framer for frame for reared clone
+
+        """
 
         console.profuse("         Cloning '{0}' as '{1}' be '{2}'\n".format(
                 original.name, clone, ScheduleNames.get(schedule, schedule)))
@@ -1410,24 +1403,24 @@ class Rearer(Actor):
                                                                          self._act.count))
                 return
 
-
-            clone = framing.Framer.nameUid(prefix=original.name)
-            while (clone in framing.Framer.Names): # ensure unique
-                clone = framing.Framer.nameUid(prefix=original.name)
-
-            console.terse("         Cloning original '{0}' as aux insular clone"
-                          " '{1}' of Frame '{2}'\n".format(original.name,
-                                                           clone,
-                                                           frame.name))
-
-            clone = original.clone(name=clone, schedule=schedule)
-            self._act.frame.framer.assignFrameRegistry()  # restore original.clone changes
+            tag = framer.newAuxTag(base=original.tag)
+            name = "_".join((framer.surname, tag))  # replace name with full name
+            console.terse("         Rearing original '{0}' as aux insular clone"
+                          " '{1}' in Frame '{2}' in Framer '{3}'"
+                          "\n".format(original.name,
+                                        name,
+                                        frame.name,
+                                        framer.name))
+            clone = original.clone(name=name, tag=tag, schedule=schedule)
             clone.original = False  # main frame will be fixed
             clone.insular = True  #  local to this framer
             clone.razeable = True  # can be razed
+            framer.auxes[tag] = clone
             frame.addAux(clone)
             clone.main = frame
-            self.store.house.resolvables.append(clone)
+            #self._act.frame.framer.assignFrameRegistry()  # setup for resolution
+            self.store.house.presolvables.append(clone)
+            self.store.house.presolvePresolvables()
             self.store.house.resolveResolvables()
 
 
@@ -1448,7 +1441,7 @@ class Razer(Actor):
         parms = super(Razer, self)._resolve( **kwa)
 
 
-        framer = framing.resolveFramer(self._act.frame.framer,
+        parms['framer'] = framer = framing.resolveFramer(self._act.frame.framer,
                                         who=self._act.frame.name,
                                         desc='rear aux clone',
                                         contexts=[],
@@ -1468,8 +1461,15 @@ class Razer(Actor):
 
         return parms
 
-    def action(self, who, frame, **kw):
-        """Action called by Actor  """
+    def action(self, who, frame, framer, **kw):
+        """
+        Action called by Actor
+
+        Parameters:
+           who is string describing which aux(es) to raze
+           frame is frame with auxes to raze
+           framer is framer of frame with auxes to raze
+        """
 
         razeables = []
         if who == 'all':
@@ -1478,12 +1478,12 @@ class Razer(Actor):
                     razeables.append(aux)
 
         elif who == 'first':
-            for aux in frame.auxes:
+            for aux in frame.auxes:  # works even if .auxes empty
                 if aux.insular and aux.razeable:
                     razeables.append(aux)
                     break
 
-        elif who == 'last':
+        elif who == 'last':  # works even if .auxes empty
             for aux in reversed(frame.auxes):
                 if aux.insular and aux.razeable:
                     razeables.append(aux)
@@ -1493,3 +1493,5 @@ class Razer(Actor):
             console.concise("         Razing '{0}' in '{1}'\n".format(who, frame.name))
             aux.prune()
             frame.auxes.remove(aux)
+            if aux.tag in framer.auxes:
+                del framer.auxes[aux.tag]
