@@ -8,8 +8,6 @@ from ioflo import test
 test.run()
 
 """
-#print("\nPackage at {0}".format( __path__[0]))
-
 import sys
 if sys.version_info < (2, 7):
     import unittest2 as unittest
@@ -22,14 +20,16 @@ from ioflo.aid.consoling import getConsole
 console = getConsole()
 console.reinit(verbosity=console.Wordage.concise)
 
-top = os.path.dirname(os.path.dirname
-                     (os.path.abspath
-                     (sys.modules.get(__name__).__file__)))
+start = os.path.dirname(os.path.dirname
+                        (os.path.abspath
+                            (sys.modules.get(__name__).__file__)))
+
+# need top to be above root for relative imports to not go above top level
+top = os.path.dirname(start)
 
 def run(top, start=None):
     """
-    Run unittests starting at directory given by start
-    Default start is the location of the ioflo.base package
+    Run unittests starting at directory given by start within the package rooted at top
     """
     if not start:
         start = top
@@ -40,4 +40,4 @@ def run(top, start=None):
     unittest.TextTestRunner(verbosity=2).run(suite)
 
 if __name__ == "__main__":
-    run(top)
+    run(top, start)
